@@ -1,63 +1,43 @@
 apclusterL.matrix <- function(s, x, sel, p=NA, q=NA, maxits=1000, convits=100,
-                              lam=0.9, includeSim=FALSE, nonoise=FALSE, seed=NA)
+                              lam=0.9, nonoise=FALSE, seed=NA)
 {
-    if (!is.na(seed)) set.seed(seed)
-
-    #
-    # check input data
-    #
-    if (length(dim(s)) != 2)
-        stop("s must be a matrix")
-
     M <- ncol(s)
     N <- nrow(s)
 
-    if (M > N)
-        stop("no. of columns of s may not be larger than number of rows")
-
-    if (!is.vector(sel) || !is.numeric(sel))
-        stop("sel must be a numeric vector")
-
-    if (length(sel) != M)
-        stop("vector sel is shorter or longer than number of selected samples")
-
-    if (max(sel) > N || min(sel) < 1)
-        stop("sample index in sel must be between one and number of samples")
+    if (!is.na(seed)) set.seed(seed)
 
     if (!is.na(p[1]) && (!is.numeric(p) || !is.vector(p)))
-        stop("p must be a number or vector")
+        stop("'p' must be a number or vector")
 
     if (length(p) > 1)
     {
         if (length(p) < N)
-            stop("vector p is shorter than number of samples")
+            stop("vector 'p' is shorter than number of samples")
         else if (length(p) > N)
             p <- p[1:N] # truncate unnecessarily long p
     }
 
     if (any(is.na(p)) && !is.na(q) && !is.numeric(q))
-        stop("q must be a number")
+        stop("'q' must be a number")
 
     if (lam > 0.9)
-        warning("Large damping factor in use. The algorithm\n",
+        warning("large damping factor in use; the algorithm\n",
                 "will change decisions slowly, so consider using\n",
-                "a larger value of convits.")
+                "a larger value of 'convits'.")
 
     # If argument p is not given, p is set to median of s
     if (any(is.na(p)))
     {
         if (is.na(q))
-            p <- median(s[setdiff(which(s > -Inf), (1:M-1) * N + sel)])
+            p <- median(s[setdiff(which(s > -Inf), (1:M - 1) * N + sel)])
         else
-            p <- quantile(s[setdiff(which(s > -Inf), (1:M-1) * N + sel)], q)
+            p <- quantile(s[setdiff(which(s > -Inf), (1:M - 1) * N + sel)], q)
     }
 
     attributes(p) <- NULL
 
     apresultObj <- new("APResult") # create the result object to be returned
 
-    apresultObj@call <- deparse(sys.call(-1))
-
     # store p into result object for future reference
     apresultObj@p <- p
 
@@ -72,7 +52,7 @@ apclusterL.matrix <- function(s, x, sel, p=NA, q=NA, maxits=1000, convits=100,
     # input similarities
     if (!nonoise)
     {
-        randomMat <- matrix(rnorm(N*M),N,M)
+        randomMat <- matrix(rnorm(N * M), N, M)
 
         s <- s + (.Machine$double.eps * s + .Machine$double.xmin * 100) *
                  randomMat
@@ -91,7 +71,7 @@ apclusterL.matrix <- function(s, x, sel, p=NA, q=NA, maxits=1000, convits=100,
 
     if (length(infelem) > 0)
         stop("+Inf similarities detected: change to a large positive value,",
-             " but smaller than realmax")
+             " but smaller than ", .Machine$double.xmax)
 
     # convert to C sample indices
     selC <- sel - 1
@@ -102,36 +82,23 @@ apclusterL.matrix <- function(s, x, sel, p=NA, q=NA, maxits=1000, convits=100,
     K <- res$K
 
     # convert cluster center indices to R
-    I <- res$I[1:K] + 1
     i <- res$it
 
     if (K > 0)
     {
         i <- i + 1
-
+        I <- res$I[1:K] + 1
+        I <- I[I %in% sel]
         ee <- which(sel %in% I)
-        if (length(ee) < 1)
-            stop("Internal error: no exemplars in selected samples")
+        K <- length(ee)
+
+        if (K < 1)
+            stop("internal error: no exemplars in selected samples")
 
-        # select exemplar with the highest similarity
-        # diagonal elements are not relevant, they are
-        # overwritten with 1:K
         c <- rep(NA, N)
-        for (j in 1:N)
-        {
-            if (j %in% sel[ee])
-            {
-                sc <- s[j,ee]
-                sc[which(j %in% sel[ee])] <- s[j, M + 1]
-                c[j] <- which(I %in% sel[ee[which.max(sc)]])
-            }
-            else
-            {
-                c[j] <- which(I %in% sel[ee[which.max(s[j, ee])]])
-            }
-        }
-
-        c[I] <- 1:K # Identify clusters
+        c[I] <- 1:K
+        nonI <- setdiff(1:N, I)
+        c[nonI] <- sapply(nonI, function(ii) which.max(s[ii, ee]))
         c[is.na(c)] <- 0 # R inserts NAs by default, so replace them with 0s
                          # to get the same result as the Matlab code
 
@@ -142,47 +109,35 @@ apclusterL.matrix <- function(s, x, sel, p=NA, q=NA, maxits=1000, convits=100,
             ii <- which(sel %in% jj)
             ns <- s[jj, M + 1]
 
-            if (length(ii) > 0)
-            {
-                ns[match(sel[ii],jj)] <- colSums(s[jj, ii, drop=FALSE]) +
-                                         s[sel[ii], M + 1] -
-                                             diag(s[sel[ii], ii, drop=FALSE])
-                I[k] <- jj[match(sel[ii],jj)[which.max(ns[match(sel[ii], jj)])]]
-            }
-            else
-            {
-                if (length(jj) > 1)
-                    stop("Internal error: wrong number of exemplar candidates")
-            }
+            ind <- match(sel[ii], jj)
+            ns[ind] <- colSums(s[jj, ii, drop=FALSE]) +
+                       s[sel[ii], M + 1] - diag(s[sel[ii], ii, drop=FALSE])
+            I[k] <- jj[ind[which.max(ns[ind])]]
         }
 
-        names(I) <- rownames(s)[I]
-        notI <- matrix(sort(setdiff(1:N, I)), ncol=1)
+        I <- sort(I)
+
+        if (length(rownames(s)) > 0)
+            names(I) <- rownames(s)[I]
+
+        nonI <- setdiff(1:N, I)
 
         ee <- which(sel %in% I)
 
-        for (j in 1:N)
-        {
-            if (j %in% sel[ee])
-            {
-                sc <- s[j, ee]
-                sc[which(j %in% sel[ee])] <- s[j, M + 1]
-                c[j] <- which(I %in% sel[ee[which.max(sc)]])
-            }
-            else
-                 c[j] <- which(I %in% sel[ ee[which.max(s[j, ee])]])
-        }
-
+        c <- rep(NA, N)
         c[I] <- 1:K
+        nonI <- setdiff(1:N, I)
+        c[nonI] <- sapply(nonI, function(ii) which.max(s[ii, ee]))
+        c[is.na(c)] <- 0 # R inserts NAs by default, so replace them with 0s
+                         # to get the same result as the Matlab code
         tmpidx <- I[c]
 
         # Self similarities not relevant
-        tmpdpsim <- sum(s[sub2ind(N, notI, match(tmpidx[notI], sel))])
+        tmpdpsim <- sum(s[sub2ind(N, nonI, match(tmpidx[nonI], sel))])
         tmpexpref <- sum(s[I, M + 1])
         tmpnetsim <- tmpdpsim + tmpexpref
 
-        apresultObj@exemplars <- as.numeric(levels(factor(tmpidx)))
-
+        apresultObj@exemplars <- I
         apresultObj@clusters <- list()
 
         for (c in 1:length(apresultObj@exemplars))
@@ -216,28 +171,60 @@ apclusterL.matrix <- function(s, x, sel, p=NA, q=NA, maxits=1000, convits=100,
     apresultObj@it     <- i
 
     if (res$unconv)
-        warning("Algorithm did not converge. Turn on details\n",
+        warning("algorithm did not converge; turn on details\n",
                 "and call plot() to monitor net similarity. Consider\n",
-                "increasing maxits and convits, and, if oscillations occur\n",
-                "also increasing damping factor lam.")
-
-    apresultObj@call <- deparse(sys.call(-1))
-
-    if (includeSim)
-        apresultObj@sim <- s
+                "increasing 'maxits' and 'convits', and, ",
+                "if oscillations occur,\n",
+                "also increasing damping factor 'lam'.")
 
     apresultObj
 }
 
-setMethod("apclusterL", signature(s="matrix", x="missing"), apclusterL.matrix)
+setMethod("apclusterL", signature(s="matrix", x="missing"),
+          function(s, x, sel, p=NA, q=NA, maxits=1000, convits=100,
+                   lam=0.9, includeSim=FALSE, nonoise=FALSE, seed=NA)
+          {
+              M <- ncol(s)
+              N <- nrow(s)
+
+              if (M > N)
+                  stop("no. of columns of 's' may not be larger than ",
+                       "number of rows")
+
+              if (!is.vector(sel) || !is.numeric(sel))
+                  stop("'sel' must be a numeric vector")
+
+              if (length(sel) != M)
+                  stop("vector 'sel' is shorter or longer than number of ",
+                       "selected samples")
+
+              if (max(sel) > N || min(sel) < 1)
+                  stop("sample index in 'sel' must be between one and ",
+                       "number of samples")
+
+              if (length(unique(sel)) != length(sel) || is.unsorted(sel))
+                  stop("'sel' must be in strictly increasing order")
+
+              apresultObj <- apclusterL.matrix(s=s, sel=sel, p=p, q=q,
+                                               maxits=1000, convits=convits,
+                                               lam=lam, nonoise=nonoise,
+                                               seed=seed)
+
+              apresultObj@call <- deparse(sys.call(-1))
+
+              if (includeSim)
+                  apresultObj@sim <- s
+
+              apresultObj
+          })
 
 
 apclusterL.function <- function(s, x, frac, sweeps, p=NA, q=NA,
                                 maxits=1000, convits=100, lam=0.9,
                                 includeSim=TRUE, nonoise=FALSE, seed=NA, ...)
 {
-    if (frac <=0 || frac > 1)
-        stop("Invalid fraction of samples specified")
+    if (frac <= 0 || frac > 1)
+        stop("invalid fraction of samples specified")
 
     if (!is.na(seed)) set.seed(seed)
 
@@ -249,7 +236,8 @@ apclusterL.function <- function(s, x, frac, sweeps, p=NA, q=NA,
     else
         N <- length(x)
 
-    if (N < 2) stop("cannot cluster less than 2 samples")
+    if (N < 2)
+        stop("cannot cluster less than 2 samples")
 
     nsel <- max(ceiling(N * frac), 2)
     sel <- sort(sample(1:N, nsel))
@@ -257,7 +245,7 @@ apclusterL.function <- function(s, x, frac, sweeps, p=NA, q=NA,
     if (!is.function(s))
     {
         if (!is.character(s) || !exists(s, mode="function"))
-            stop("Invalid distance function")
+            stop("invalid distance function")
 
         s <- match.fun(s)
     }
@@ -271,10 +259,10 @@ apclusterL.function <- function(s, x, frac, sweeps, p=NA, q=NA,
         sim <- s(x=x, sel=sel, ...)
 
         if (!is.matrix(sim) || nrow(sim) != N || ncol(sim) != length(sel))
-            stop("Computation of similarity matrix failed")
+            stop("computation of similarity matrix failed")
 
-        apres <- apclusterL(s=sim, sel=sel, p=p, q=q, maxits=maxits,
-                            convits=convits, lam=lam, nonoise=nonoise)
+        apres <- apclusterL.matrix(s=sim, sel=sel, p=p, q=q, maxits=maxits,
+                                   convits=convits, lam=lam, nonoise=nonoise)
 
         netsimL[i] <- apres@netsim
 
